@@ -1,10 +1,30 @@
 use strict;
 package Catalyst::Helper::View::Text::Template;
+{
+  $Catalyst::Helper::View::Text::Template::VERSION = '0.009';
+}
+# ABSTRACT: Helper for Text::Template Views
+
+
+sub mk_compclass {
+  my ($self, $helper) = @_;
+  my $file = $helper->{file};
+  $helper->render_file('compclass', $file);
+}
+
+
+1;
+
+=pod
 
 =head1 NAME
 
 Catalyst::Helper::View::Text::Template - Helper for Text::Template Views
 
+=head1 VERSION
+
+version 0.009
+
 =head1 SYNOPSIS
 
   script/create.pl view NameOfMyView Text::Template 
@@ -13,45 +33,47 @@ Catalyst::Helper::View::Text::Template - Helper for Text::Template Views
 
 Helper for Text::Template Views.
 
-=head2 METHODS
+=head1 METHODS
 
-=head3 mk_compclass
-
-=cut
-
-sub mk_compclass {
-  my ($self, $helper) = @_;
-  my $file = $helper->{file};
-  $helper->render_file('compclass', $file);
-}
+=head2 mk_compclass
 
 =head1 SEE ALSO
 
 L<Catalyst::Manual>, L<Catalyst::Test>, L<Catalyst::Request>,
 L<Catalyst::Response>, L<Catalyst::Helper>, L<Catalyst::View::Text::Template>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Dean Hamstead, C<dean@fragfest.com.au>
+=over 4
 
-=head1 LICENSE
+=item *
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as perl itself.
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Dean Hamstead <dean@fragfest.com.au>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2004 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
-
 __DATA__
 
 __compclass__
 package [% class %];
 
-use strict;
-use warnings;
+use Moose;
+use namespace::autoclean;
 
-use parent 'Catalyst::View::Text::Template';
+extends 'Catalyst::View::Text::Template';
 
 __PACKAGE__->config(TEMPLATE_EXTENSION => '.tmpl');
 
